@@ -1,41 +1,30 @@
+#include <algorithm>
 #include <atomic>
+#include <cassert>
 #include <cerrno>
+#include <chrono>
 #include <cstddef>
 #include <cstdint>
-#include <utility>
-#include <algorithm>
-#include <chrono>
 #include <exception>
+#include <future>
+#include <iostream>
 #include <iterator>
 #include <limits>
+#include <mutex>
 #include <stdexcept>
 #include <string>
-#include <vector>
 #include <thread>
-#include <mutex>
-#include <cassert>
-#include <iostream>
+#include <utility>
+#include <vector>
 
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wdeprecated"
-#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
-#include <caf/behavior.hpp>
-#include <caf/config.hpp>
-#include <caf/config_option_adder.hpp>
-#include <caf/deep_to_string.hpp>
-#include <caf/downstream.hpp>
-#include <caf/event_based_actor.hpp>
-#include <caf/exit_reason.hpp>
-#include <caf/send.hpp>
-#include <caf/type_id.hpp>
-#pragma GCC diagnostic pop
-
-#include "broker/atoms.hh"
 #include "broker/config.hh"
 #include "broker/configuration.hh"
 #include "broker/convert.hh"
 #include "broker/data.hh"
 #include "broker/endpoint.hh"
+#include "broker/internal/configuration_access.hh"
+#include "broker/internal/endpoint_access.hh"
+#include "broker/internal/type_id.hh"
 #include "broker/publisher.hh"
 #include "broker/status.hh"
 #include "broker/subscriber.hh"
@@ -45,6 +34,8 @@
 #include <sys/select.h>
 #endif // BROKER_WINDOWS
 
+namespace atom = broker::internal::atom;
+
 using broker::data;
 using broker::data_message;
 using broker::make_data_message;
@@ -57,6 +48,7 @@ std::mutex cout_mtx;
 using guard_type = std::unique_lock<std::mutex>;
 
 bool rate = false;
+
 std::atomic<size_t> msg_count{0};
 
 void print_line(std::ostream& out, const std::string& line) {
@@ -66,39 +58,30 @@ void print_line(std::ostream& out, const std::string& line) {
 
 struct parameters {
   std::string mode;
-  std::string impl;
+  std::string impl = "blocking";
   std::string topic;
   std::vector<std::string> peers;
-  uint16_t local_port = 0;
-  size_t message_cap = std::numeric_limits<size_t>::max();
+  uint64_t local_port = 0;
+  uint64_t message_cap = std::numeric_limits<uint64_t>::max();
 };
 
-class config : public broker::configuration {
-public:
-  using super = broker::configuration;
-
-  config(parameters* param) : super(skip_init) {
-    assert(param != nullptr);
-    opt_group{custom_options_, "global"}
-    .add<bool>(rate, "rate,r",
-               "print the rate of messages once per second instead of the "
-               "message content")
-    .add(param->peers, "peers,p",
-         "list of peers we connect to on startup (host:port notation)")
-    .add(param->local_port, "local-port,l",
-         "local port for publishing this endpoint at (ignored if 0)")
-    .add(param->topic, "topic,t",
-         "topic for sending/receiving messages")
-    .add(param->mode, "mode,m",
-         "set mode ('publish' or 'subscribe')")
-    .add(param->impl, "impl,i",
-         "set mode implementation ('blocking', 'select', or 'stream')")
-    .add(param->message_cap, "message-cap,c",
-         "set a maximum for received/sent messages");
-  }
-
-  using super::init;
-};
+// Adds custom configuration options to the config object.
+void extend_config(parameters& param, broker::configuration& cfg) {
+  cfg.add_option(&rate, "rate,r",
+                 "print the rate of messages once per second instead of the "
+                 "message content");
+  cfg.add_option(&param.peers, "peers,p",
+                 "list of peers we connect to on startup (host:port notation)");
+  cfg.add_option(&param.local_port, "local-port,l",
+                 "local port for publishing this endpoint at (ignored if 0)");
+  cfg.add_option(&param.topic, "topic,t",
+                 "topic for sending/receiving messages");
+  cfg.add_option(&param.mode, "mode,m", "set mode ('publish' or 'subscribe')");
+  cfg.add_option(&param.impl, "impl,i",
+                 "set mode implementation ('blocking', 'select', or 'stream')");
+  cfg.add_option(&param.message_cap, "message-cap,c",
+                 "set a maximum for received/sent messages");
+}
 
 void publish_mode_blocking(broker::endpoint& ep, const std::string& topic_str,
                            size_t cap) {
@@ -109,6 +92,7 @@ void publish_mode_blocking(broker::endpoint& ep, const std::string& topic_str,
     out.publish(std::move(line));
     ++msg_count;
   }
+  std::cout << "*** published " << msg_count << " messages, byte\n";
 }
 
 #ifdef BROKER_WINDOWS
@@ -147,29 +131,6 @@ void publish_mode_select(broker::endpoint& ep, const std::string& topic_str,
 
 #endif // BROKER_WINDOWS
 
-void publish_mode_stream(broker::endpoint& ep, const std::string& topic_str,
-                         size_t cap) {
-  auto worker = ep.publish_all(
-    [](size_t& msgs) { msgs = 0; },
-    [=](size_t& msgs, caf::downstream<data_message>& out, size_t hint) {
-      auto num = std::min(cap - msgs, hint);
-      std::string line;
-      for (size_t i = 0; i < num; ++i)
-        if (!std::getline(std::cin, line)) {
-          // Reached end of STDIO.
-          msgs = cap;
-          return;
-        } else {
-          out.push(make_data_message(topic_str, std::move(line)));
-        }
-      msgs += num;
-      msg_count += num;
-    },
-    [=](const size_t& msgs) { return msgs == cap; });
-  caf::scoped_actor self{ep.system()};
-  self->wait_for(worker);
-}
-
 void subscribe_mode_blocking(broker::endpoint& ep, const std::string& topic_str,
                     size_t cap) {
   auto in = ep.make_subscriber({topic_str});
@@ -177,7 +138,7 @@ void subscribe_mode_blocking(broker::endpoint& ep, const std::string& topic_str,
   for (size_t i = 0; i < cap; ++i) {
     auto msg = in.get();
     if (!rate)
-      print_line(std::cout, deep_to_string(std::move(msg)));
+      print_line(std::cout, to_string(msg));
     ++msg_count;
   }
 }
@@ -207,7 +168,7 @@ void subscribe_mode_select(broker::endpoint& ep, const std::string& topic_str,
     for (size_t j = 0; j < num; ++j) {
       auto msg = in.get();
       if (!rate)
-        print_line(std::cout, deep_to_string(std::move(msg)));
+        print_line(std::cout, to_string(msg));
     }
     i += num;
     msg_count += num;
@@ -219,67 +180,83 @@ void subscribe_mode_select(broker::endpoint& ep, const std::string& topic_str,
 void subscribe_mode_stream(broker::endpoint& ep, const std::string& topic_str,
                     size_t cap) {
   auto worker = ep.subscribe(
+    // Filter.
     {topic_str},
-    [](size_t& msgs) {
-      msgs = 0;
-    },
-    [=](size_t& msgs, data_message x) {
+    // Init.
+    [](size_t& msgs) { msgs = 0; },
+    // OnNext.
+    [cap](size_t& msgs, data_message x) {
       ++msg_count;
       if (!rate)
-        print_line(std::cout, deep_to_string(x));
+        print_line(std::cout, to_string(x));
       if (++msgs >= cap)
         throw std::runtime_error("Reached cap");
     },
-    [=](size_t&, const caf::error&) {
+    [=](size_t&, const broker::error&) {
       // nop
-    }
-  );
-  caf::scoped_actor self{ep.system()};
-  self->wait_for(worker);
+    });
+  ep.wait_for(worker);
 }
-
-caf::behavior event_listener(caf::event_based_actor* self) {
-  self->join(self->system().groups().get_local("broker/errors"));
-  self->join(self->system().groups().get_local("broker/statuses"));
-  auto print = [](std::string what) {
-    what.insert(0, "*** ");
-    what.push_back('\n');
-    guard_type guard{cout_mtx};
-    std::cerr << what;
-  };
-  return {
-    [=](broker::atom::local, broker::error& x) { print(to_string(x)); },
-    [=](broker::atom::local, broker::status& x) { print(to_string(x)); },
-  };
+void split(std::vector<std::string>& result, std::string_view str,
+           std::string_view delims, bool keep_all = true) {
+  size_t pos = 0;
+  size_t prev = 0;
+  while ((pos = str.find_first_of(delims, prev)) != std::string::npos) {
+    auto substr = str.substr(prev, pos - prev);
+    if (keep_all || !substr.empty())
+      result.emplace_back(substr);
+    prev = pos + 1;
+  }
+  if (prev < str.size())
+    result.emplace_back(str.substr(prev));
+  else if (keep_all)
+    result.emplace_back(std::string{});
 }
 
 } // namespace <anonymous>
 
 int main(int argc, char** argv) {
+  broker::endpoint::system_guard sys_guard;
   // Parse CLI parameters using our config.
   parameters params;
-  config cfg{&params};
+  broker::configuration cfg{broker::skip_init};
+  extend_config(params, cfg);
   try {
     cfg.init(argc, argv);
   } catch (std::exception& ex) {
     std::cerr << "*** error while reading config: " << ex.what() << '\n';
     return EXIT_FAILURE;
   }
-  if (cfg.cli_helptext_printed) {
+  if (cfg.cli_helptext_printed()) {
     return EXIT_SUCCESS;
-  } else if (!cfg.remainder.empty()) {
+  } else if (!cfg.remainder().empty()) {
     std::cerr << "*** too many arguments\n\n";
     return EXIT_FAILURE;
   }
   broker::endpoint ep{std::move(cfg)};
-  auto el = ep.system().spawn(event_listener);
+  ep.subscribe(
+    {topic::errors(), topic::statuses()},
+    [] {
+      // Init: nop.
+    },
+    [=](const data_message& x) {
+      // OnNext: print the message.
+      std::string what = to_string(x);
+      what.insert(0, "*** ");
+      what.push_back('\n');
+      guard_type guard{cout_mtx};
+      std::cerr << what;
+    },
+    [=](const broker::error&) {
+      // Cleanup: nop.
+    });
   // Publish endpoint at demanded port.
   if (params.local_port != 0)
     ep.listen({}, params.local_port);
   // Connect to the requested peers.
   for (auto& p : params.peers) {
     std::vector<std::string> fields;
-    caf::split(fields, p, ':');
+    split(fields, p, ":");
     if (fields.size() != 2) {
       guard_type guard{cout_mtx};
       std::cerr << "*** invalid peer: " << p << std::endl;
@@ -316,7 +293,6 @@ int main(int argc, char** argv) {
   mode_fun fs[] = {
     publish_mode_blocking,
     publish_mode_select,
-    publish_mode_stream,
     subscribe_mode_blocking,
     subscribe_mode_select,
     subscribe_mode_stream,
@@ -325,7 +301,6 @@ int main(int argc, char** argv) {
   std::pair<std::string, std::string> as[] = {
     {"publish", "blocking"},
     {"publish", "select"},
-    {"publish", "stream"},
     {"subscribe", "blocking"},
     {"subscribe", "select"},
     {"subscribe", "stream"},
@@ -334,5 +309,4 @@ int main(int argc, char** argv) {
   auto i = std::find(b, std::end(as), std::make_pair(params.mode, params.impl));
   auto f = fs[std::distance(b, i)];
   f(ep, params.topic, params.message_cap);
-  anon_send_exit(el, caf::exit_reason::user_shutdown);
 }
